pub fn host_current_process_privilege() -> Result<Option<PrivilegedIdentity>>Expand description
The privileged identity this process is running as, if any.
pub fn host_current_process_privilege() -> Result<Option<PrivilegedIdentity>>The privileged identity this process is running as, if any.