process_open_loaded_image_file

Function process_open_loaded_image_file 

pub fn process_open_loaded_image_file(image: &LoadedImage) -> Option<File>
Reopen the file behind image, refusing one that no longer has the device and inode recorded in /proc/self/maps.