Module private_dir

Module private_dir 

Owner-private directory permissions without local-IPC transport selection.

Persisted registration records use the same host policy as IPC roots, but do not need a listener, endpoint naming, or transport implementation.