pub enum SyncEnvironment {
Inherit,
Explicit(Vec<(OsString, OsString)>),
}Expand description
Environment base selected by the shared caller for a synchronous spawn.
Explicit Command::env additions and removals remain on the command and
are applied after this base by the selected platform implementation.
Variants
Inherit
Start with the spawning process’s ambient environment.
Explicit(Vec<(OsString, OsString)>)
Start with this complete, caller-assembled base environment.