pub struct ProcessInspectError {
pub kind: ProcessInspectErrorKind,
pub source: Error,
}Expand description
A failure to inspect or signal a process, and what kind of failure it was.
Fields
kind: ProcessInspectErrorKindWhich of the four situations this is.
source: ErrorWhat the host reported.
Implementations
Sourceimpl ProcessInspectError
impl ProcessInspectError
Sourcepub fn last_os_error(kind: ProcessInspectErrorKind) -> Self
pub fn last_os_error(kind: ProcessInspectErrorKind) -> Self
Build an error of kind carrying the host’s last reported error.
Sourcepub fn stated(kind: ProcessInspectErrorKind, message: &str) -> Self
pub fn stated(kind: ProcessInspectErrorKind, message: &str) -> Self
Build an error of kind with a message this crate composed itself.