pub struct SpawnedChild {
pub stdin: Option<ChildStdin>,
pub stdout: Option<ChildStdout>,
pub stderr: Option<ChildStderr>,
/* private fields */
}Expand description
Handle and optional parent pipe ends for a contained child.
Dropping this value shuts down the contained process group.
Fields
stdin: Option<ChildStdin>Writable parent end when standard input was configured as a pipe.
stdout: Option<ChildStdout>Readable parent end when standard output was configured as a pipe.
stderr: Option<ChildStderr>Readable parent end when standard error was configured as a pipe.
Implementations
Sourceimpl SpawnedChild
impl SpawnedChild