Module terminal

Module terminal 

Terminal, PTY, console, input, and terminal-I/O primitives.

Modules

input

Structs

PtyInputChunk
One chunk read from the host terminal input source.
PtyInterruptTarget
Prepared, owned interrupt operation that can outlive a borrow of the PTY master.
PtySize
Caller-facing PTY dimensions.
TerminalGraphicsProbe
Raw replies returned by a bounded active terminal-graphics probe.

Traits

PtyBackend
Factory trait implemented by the selected host PTY backend.
PtyChild
Platform-neutral handle for a child process running inside a PTY.
PtyMaster
Platform-neutral handle for the master side of a pseudo-terminal.
PtySlave
Platform-neutral handle for the slave side of a pseudo-terminal.

Functions

active_graphics_probe
Probe the controlling terminal without exposing terminal descriptors.

Type Aliases

SharedPtyWriter
Independently lockable writer used by the PTY session policy layer.