PlatformOutput

Struct PlatformOutput 

pub struct PlatformOutput { /* private fields */ }
Opaque stdout or stderr reader owned by a process actor.

Implementations

Source

impl PlatformOutput

pub async fn read_to_end(self) -> Result<Vec<u8>>

Drain this output endpoint to EOF without blocking a runtime worker.

pub async fn read_chunk(&mut self, buffer: &mut [u8]) -> Result<usize>

Read the next asynchronous chunk from this output endpoint.

The caller owns the buffer and therefore controls the amount of data retained at each read. EOF is reported as Ok(0).